Crate folio_font

Crate folio_font 

PDF font handling — loading, metrics, encoding, and Unicode mapping.

Structs

Encoding
An encoding that can map character codes to Unicode strings.
PdfFont
A loaded PDF font with encoding and metrics.
ToUnicodeCMap
A parsed ToUnicode CMap.

Enums

FontType
PDF font types.
PdfEncoding
Known PDF text encodings.

Constants

STANDARD_14_METRICS
Built-in metrics for the standard 14 fonts.

Functions

decode_text
Decode text bytes using the appropriate encoding for a font.