PDF font handling — loading, metrics, encoding, and Unicode mapping.
Structs
- Encoding
- An encoding that can map character codes to Unicode strings.
- PdfFont
- A loaded PDF font with encoding and metrics.
- ToUnicodeC
Map - A parsed ToUnicode CMap.
Enums
- Font
Type - PDF font types.
- PdfEncoding
- Known PDF text encodings.
Constants
- STANDARD_
14_ METRICS - Built-in metrics for the standard 14 fonts.
Functions
- decode_
text - Decode text bytes using the appropriate encoding for a font.